@@ -13,7 +13,7 @@ use std::{fs, path::Path, str};
 
 #[cfg(feature = "pem")]
 use {
-    crate::{pem, public_key::PEM_TYPE_LABEL},
+    crate::{pem, public_key::PEM_TYPE_LABEL, LineEnding},
     alloc::string::String,
     core::str::FromStr,
 };
@@ -85,8 +85,8 @@ impl ToRsaPublicKey for RsaPublicKeyDocument {
 
     #[cfg(feature = "pem")]
     #[cfg_attr(docsrs, doc(cfg(feature = "pem")))]
-    fn to_pkcs1_pem(&self) -> Result<String> {
-        Ok(pem::encode_string(PEM_TYPE_LABEL, &self.0)?)
+    fn to_pkcs1_pem_with_le(&self, line_ending: LineEnding) -> Result<String> {
+        Ok(pem::encode_string(PEM_TYPE_LABEL, line_ending, &self.0)?)
     }
 
     #[cfg(feature = "std")]
