@@ -11,7 +11,11 @@ use der::{
 use crate::RsaPrivateKeyDocument;
 
 #[cfg(feature = "pem")]
-use {crate::pem, alloc::string::String, zeroize::Zeroizing};
+use {
+    crate::{pem, LineEnding},
+    alloc::string::String,
+    zeroize::Zeroizing,
+};
 
 /// Type label for PEM-encoded private keys.
 #[cfg(feature = "pem")]
@@ -87,7 +91,15 @@ impl<'a> RsaPrivateKey<'a> {
     #[cfg(feature = "pem")]
     #[cfg_attr(docsrs, doc(cfg(feature = "pem")))]
     pub fn to_pem(&self) -> Result<Zeroizing<String>> {
-        let pem_doc = pem::encode_string(PEM_TYPE_LABEL, self.to_der().as_ref())?;
+        self.to_pem_with_le(LineEnding::default())
+    }
+
+    /// Encode this [`RsaPrivateKey`] as PEM-encoded ASN.1 DER using the given
+    /// [`LineEnding`].
+    #[cfg(feature = "pem")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "pem")))]
+    pub fn to_pem_with_le(&self, line_ending: LineEnding) -> Result<Zeroizing<String>> {
+        let pem_doc = pem::encode_string(PEM_TYPE_LABEL, line_ending, self.to_der().as_ref())?;
         Ok(Zeroizing::new(pem_doc))
     }
 }
